@@ -1,11 +1,11 @@
 getUser <- function(user, session=getCurlHandle()) {
     if (inherits(user, "user"))
-        user <- user@screenName
+        user <- screenName(user)
 
     ## For god knows what reason, my normal methods don't work here,
     ## build URL by hand
     url <- paste("http://twitter.com/users/show.json?screen_name=",
-                 user, sep="")
+                 URLencode(user), sep="")
     out <- getURL(url, curl=session)
     ## Need some error checking
     buildUser(twFromJSON(out))
@@ -13,11 +13,11 @@ getUser <- function(user, session=getCurlHandle()) {
 
 userFriends <- function(user, session=getCurlHandle()) {
     if (inherits(user, "user"))
-        user <- user@screenName
+        user <- screenName(user)
     ## For god knows what reason, my normal methods don't work here,
     ## build URL by hand
     url <- paste("http://twitter.com/statuses/friends.json?screen_name=",
-                 user, sep="")
+                 URLencode(user), sep="")
     out <- getURL(url, curl=session)
     ## Need some error checking
     jsonList <- twFromJSON(out)
@@ -26,11 +26,11 @@ userFriends <- function(user, session=getCurlHandle()) {
 
 userFollowers <- function(user, session=getCurlHandle()) {
     if (inherits(user, "user"))
-        user <- user@screenName
+        user <- screenName(user)
     ## For god knows what reason, my normal methods don't work here,
     ## build URL by hand
     url <- paste("http://twitter.com/statuses/followers.json?screen_name=",
-                 user, sep="")
+                 URLencode(user), sep="")
     out <- getURL(url, curl=session)
     ## Need some error checking
     jsonList <- twFromJSON(out)
